@@ -100,6 +100,9 @@ class OptimizerMPModel(parallel_model.ParallelModel):
         else:
             return linear_model_pb2.LinearModelSolutionStatusProto.Name(status)
 
+    def get_variables(self):
+        return self.mp_model.variable_list
+
     def build_model_from_solution(self, linear_model_solution_proto):
         self.mp_model = mp_model.OptMPModel(self.model_name)
 
